package metier;
import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import static javax.swing.JOptionPane.WARNING_MESSAGE;

/**
 * Classe Guerrier, hérite de la classe Personnage
 * @author Dominique_2
 * @version 20210311
 */
public class Guerrier extends Personnage{
    // Variable membre
    private String arme;

    /**
     * Valorisation des variables membres
     * @param nom       nom du guerrier
     * @param img       nom de l'image représentant le guerrier
     * @param energie   valeur énergétique du guerrier
     * @param dureeVie  durée de vie du guerrier
     * @param arme      armu du guerrier
     */
    public Guerrier(String nom, String img, int energie, int dureeVie, String arme) {
        super(nom, img, energie, dureeVie);
        this.arme = arme;
    }
    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return super.toString() + "\n\tGuerrier{" + "arme=" + arme + '}';
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (13 * hash + Objects.hashCode(this.arme));
        return hash;
    }
    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Guerrier other = (Guerrier) obj;
        if (!Objects.equals(this.arme, other.arme)) {
            return false;
        }
        if(!super.equals(obj)){
            return false;
        }
        return true;
    }

    /**
     * Get the value of arme     *
     * @return the value of arme
     */
    public String getArme() {
        return arme;
    }

    /**
     * Set the value of arme     *
     * @param arme new value of arme
     */
    public void setArme(String arme) {
        this.arme = arme;
    }

    /**
     * Rencontre du guerrier avec un autre personnage (Combat de dés)
     * @param p
     */ 
    @Override
    public void rencontrer(Personnage p) {
        Icon iCombat; 
        Icon iDes = new javax.swing.ImageIcon(getClass().getResource("../img/des.jpg"));
        int score1 = 0;
        int score2 = 0;
        int nbJeu = 0;
        String message = "Es-tu prêt à me combattre " + p.getNom() + " ? " ;
        String titre = this.getNom() + " rencontre " + p.getNom() + " : ";        
        while (score1 == score2) {
            if (nbJeu > 0) {
                message = "Égalité. Rejoue vite ";
            }
            JOptionPane.showMessageDialog( null, 
                                        message, 
                                        titre + "défi dés", 
                                        WARNING_MESSAGE,
                                        iDes);
            score1 = Jeu.genererNbAleatoire(1, 6);
            score2 = Jeu.genererNbAleatoire(1, 6);
            nbJeu++;
        }
        String resultat="Ton score : " + score2 + " - Le mien : " + score1;
        int type;
        if (score1 >= score2)  {
            resultat +=  "\n\nTu as perdu,"
                +   "\nattention à toi " + p.getNom() 
                +   ",\nta vie est en danger!";
            iCombat = new javax.swing.ImageIcon(getClass().getResource("/img/Combat.jpg"));
            p.varierDureeVie(-1);
            p.varierEnergie(-2);
        } else {
            resultat +=  "\n\nTu as gagné ce défi,"
                +   "\nmais je me vengerai de toi,\n" 
                +   p.getNom() +", prends garde à toi!";
            iCombat = new javax.swing.ImageIcon(getClass().getResource("/img/CombatPerdu.jpg"));
            p.varierEnergie(+2);    // +2 pour le gagnant attaqué
            varierEnergie(-1);      // -1 pour le perdant attaquant
        }
        JOptionPane.showMessageDialog(  null, 
                                        resultat, 
                                        titre + "résultat", 
                                        WARNING_MESSAGE,
                                        iCombat);   
    }
    
    /**
     * Rencontre avec un autre personnage 
     * @param unPerso personnage à saluer
     */
    @Override
    public void saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + ", \nsauve-toi vite avant que je ne te frappe avec mon arme redoutable!";  
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
    }
    
}
